#include "DIALOG.h"

/*********************************************************************
*
*       Externals
*
**********************************************************************
*/

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define BORDER_SIZE_X  10
#define BORDER_SIZE_Y  10

#define MESSAGE_SET_TEXT_A  (WM_USER + 0x00)
#define MESSAGE_SET_TEXT_B  (WM_USER + 0x01)
#define MESSAGE_SET_TEXT_C  (WM_USER + 0x02)

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static char * _apButtonString[] = {
  "Program A",
  "Program B",
  "Program C",
};

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
/*********************************************************************
*
*       _cbMenu
*/
static void _cbMenu(WM_MESSAGE * pMsg) {
  WM_HWIN hItem;
  int     xSize;
  int     ySize;
  int     xPosButton;
  int     yPosButton;
  int     xSizeButton;
  int     ySizeButton;
  int     i;
  int     NumItems;
  int     Id;
  int     NCode;

  switch (pMsg->MsgId) {
  case WM_CREATE:
    //
    // On creation of this window we also create buttons
    //
    // First, get the window dimensions
    //
    xSize = WM_GetWindowSizeX(pMsg->hWin);
    ySize = WM_GetWindowSizeY(pMsg->hWin);
    //
    // Number of items depends on the array entries (_apButtonString)
    //
    NumItems    = GUI_COUNTOF(_apButtonString);
    //
    // Set up x position and x/y size of the buttons
    //
    xPosButton  = BORDER_SIZE_X;
    xSizeButton = xSize - BORDER_SIZE_X * 2;
    ySizeButton = (ySize / NumItems) - (2 * BORDER_SIZE_Y);
    //
    // Itterate over the number of items
    //
    for (i = 0; i < NumItems; i++) {
      //
      // Calculate the y position of the current button
      //
      yPosButton = (ySize * i) / NumItems + BORDER_SIZE_Y;
      //
      // Create a button, the positions are relative to 'this' window
      //
      hItem = BUTTON_CreateEx(xPosButton, yPosButton, xSizeButton, ySizeButton, pMsg->hWin, WM_CF_SHOW, 0, GUI_ID_BUTTON0 + i);
      //
      // Set a text
      //
      BUTTON_SetText(hItem, _apButtonString[i]);
    }
    break;
  case WM_NOTIFY_PARENT:
    //
    // React on messages send by the child windows of 'this' window
    //
    Id    = WM_GetId(pMsg->hWinSrc);  // Get the Id of the sender
    NCode = pMsg->Data.v;             // and the notification code
    switch (Id) {
    case GUI_ID_BUTTON0:
      switch (NCode) {
      case WM_NOTIFICATION_RELEASED:
        //
        // Button 0 has been released and we send the corresponding message to the BK window
        //
        WM_SendMessageNoPara(WM_HBKWIN, MESSAGE_SET_TEXT_A);
        break;
      }
      break;
    case GUI_ID_BUTTON1:
      switch (NCode) {
      case WM_NOTIFICATION_RELEASED:
        //
        // Button 1 has been released and we send the corresponding message to the BK window
        //
        WM_SendMessageNoPara(WM_HBKWIN, MESSAGE_SET_TEXT_B);
        break;
      }
      break;
    case GUI_ID_BUTTON2:
      switch (NCode) {
      case WM_NOTIFICATION_RELEASED:
        //
        // Button 2 has been released and we send the corresponding message to the BK window
        //
        WM_SendMessageNoPara(WM_HBKWIN, MESSAGE_SET_TEXT_C);
        break;
      }
      break;
    }
    break;
  case WM_PAINT:
    GUI_SetBkColor(GUI_WHITE);
    GUI_Clear();
    break;
  default:
    WM_DefaultProc(pMsg);
    break;
  }
}

/*********************************************************************
*
*       _cbBk
*/
static void _cbBk(WM_MESSAGE * pMsg) {
  WM_HWIN hItem;
  int     Index;

  switch (pMsg->MsgId) {
  case WM_PAINT:
    //
    // Clear te background with black
    //
    GUI_SetBkColor(GUI_BLACK);
    GUI_Clear();
    break;
  case MESSAGE_SET_TEXT_A:
  case MESSAGE_SET_TEXT_B:
  case MESSAGE_SET_TEXT_C:
    //
    // On button press in the menu a message was send to the BK window, use the message ID
    // to calculate an index and acces the string array and set a new text to the TEXT widget.
    //
	//HAL_GPIO_WritePin(GPIOG, GPIO_PIN_13, GPIO_PIN_SET);
    hItem = WM_GetDialogItem(WM_HBKWIN, GUI_ID_TEXT0);
    Index = pMsg->MsgId - MESSAGE_SET_TEXT_A;
    TEXT_SetText(hItem, _apButtonString[Index]);
    break;
  default:
    WM_DefaultProc(pMsg);
    break;
  }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainTask(void) {
  WM_HWIN hText;
BUTTON_Handle hButton;
	
	WM_SetCreateFlags(WM_CF_MEMDEV);
  GUI_Init();
	
	
  //
  // Set a callback for the background window, it manages the drawing of the BK and handles messages send to it.
  //
  WM_SetCallback(WM_HBKWIN, _cbBk);
  //
  // Create a menu window as child of the background window, it gets defined and drawn in its callback function: _cbMenu
  //
  WM_CreateWindow(0, 0, 100, LCD_GetYSize(), WM_CF_SHOW, _cbMenu, 0);
	
	
  //if (BUTTON_IsPressed(hButton) == GUI_ID_BUTTON0) 
  // Create a TEXT widget as child of the background window, used to display the selected program.
  //
  hText = TEXT_CreateEx(120, LCD_GetYSize() / 2 - 20, 160, 40, WM_HBKWIN, WM_CF_SHOW, 0, GUI_ID_TEXT0, "No program selected");
  TEXT_SetTextColor(hText, GUI_WHITE);
  while (1) {
    GUI_Delay(100);
  }
}

/*************************** End of file ****************************/
